file_list=''
mod_list=''
file_list="$file_list"' clx.o'
mod_list="$mod_list"' clx'
make CC="${CC}" CFLAGS="${CFLAGS}" INCLUDES="$absolute_linkkitdir" $file_list
NEW_FILES="$file_list"
NEW_LIBS="$file_list -lXpm -lXext"
NEW_MODULES="$mod_list"
TO_LOAD='clx-ini.lsp'
TO_PRELOAD='clx-preload.lsp'
